{% extends "admin/base_site.html" %}
{% load i18n static %}

{% block extrastyle %}
    {{ block.super }}

    <link rel="stylesheet" type="text/css" href="{% static 'filer/css/admin_filer.css' %}">
{% endblock %}

{% block extrahead %}
    {{ block.super }}

    {# upload stuff #}
    {{ media.js }}
    <script type="text/javascript">
        var __jQuery = django.jQuery;
        window.jQuery = (__jQuery) ? __jQuery : window.jQuery || undefined;
        window.$ = window.jQuery;
    </script>
    <script src="{% static 'filer/js/libs/class.min.js' %}"></script>
    <script src="{% static 'filer/js/libs/jquery-ui.min.js' %}"></script>
    <script src="{% static 'filer/js/libs/dropzone.min.js' %}"></script>
    <script src="{% static 'filer/js/libs/mediator.min.js' %}"></script>
    <script src="{% static 'filer/js/libs/jquery.cookie.min.js' %}"></script>
    <script src="{% static 'filer/js/libs/fileuploader.min.js' %}"></script>
    <script src="{% static 'admin/js/admin/RelatedObjectLookups.js' %}"></script>
    <script src="{% static 'filer/js/addons/dropdown-menu.js' %}"></script>
    <script src="{% static 'filer/js/addons/popup_handling.js' %}"></script>
    <script src="{% static 'filer/js/addons/table-dropzone.js' %}"></script>
    <script src="{% static 'filer/js/addons/upload-button.js' %}"></script>
    <script src="{% static 'filer/js/addons/tooltip.js' %}"></script>
    <script src="{% static 'filer/js/addons/toggler.js' %}"></script>
    <script src="{% static 'filer/js/base.js' %}"></script>
    <script type="text/javascript">
        var __jQuery;
        var __$;
        // reassign jQuery if jQuery is already loaded
        __jQuery = (window.jQuery) ? window.jQuery.noConflict(true) : undefined;
        __$ = __jQuery;
    </script>
{% endblock %}
