# Generated by Django 3.1.8 on 2021-06-17 12:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0013_image_width_height_to_float'),
    ]

    operations = [
        migrations.AlterField(
            model_name='folderpermission',
            name='can_add_children',
            field=models.SmallIntegerField(blank=True, choices=[(None, 'inherit'), (1, 'allow'), (0, 'deny')], default=None, null=True, verbose_name='can add children'),
        ),
        migrations.AlterField(
            model_name='folderpermission',
            name='can_edit',
            field=models.SmallIntegerField(blank=True, choices=[(None, 'inherit'), (1, 'allow'), (0, 'deny')], default=None, null=True, verbose_name='can edit'),
        ),
        migrations.AlterField(
            model_name='folderpermission',
            name='can_read',
            field=models.SmallIntegerField(blank=True, choices=[(None, 'inherit'), (1, 'allow'), (0, 'deny')], default=None, null=True, verbose_name='can read'),
        ),
    ]
