{% load filer_admin_tags i18n static %}
    <section class="image-info image-info-detail">
        <div class="image-info-title">
            <span class="icon fa fa-file{% if original.file_type == 'Image' %}-image-o{% endif %}"></span> {{ original }}
        </div>
        <div class="image-details-left">
            <div class="image-preview-container">
                {% file_icon original detail=True %}
                <div class="text-left">
                {% if original.file.exists %}
                    <a href="{{ original.url }}" target="_blank" class="btn" download="{{ original.original_filename }}">
                        <span class="icon fa fa-download"></span>
                        &nbsp;<span>{% trans "Download" %}</span>
                    </a>
                    {% if original.mime_maintype == 'image' %}
                    <a href="{{ original.url }}" target="_blank" class="btn float-right">
                        <span>{% trans "Expand" %}</span>&nbsp;
                        <span class="icon fa fa-expand"></span>
                    </a>
                    {% endif %}
                {% else %}
                    <span class="warning">{% trans "File is missing" %}</span>
                {% endif %}
                </div>
            </div>
        </div>
        <div class="image-details-right">
            {% if original.file_type or original.modified_at or original.uploaded_at or original.width or original.height or original.size %}
                <dl class="image-details">
                    {% if original.file_type %}
                        <dt>{% trans "Type" %}</dt>
                        <dd>{{ original.extension|upper }} {{ original.file_type }}</dd>
                    {% endif %}
                    {% if original.width or original.height %}
                        <dt>{% trans "Size" %}</dt>
                        <dd>{{ original.width|floatformat }}x{{ original.height|floatformat }} px</dd>
                    {% endif %}
                    {% if original.size %}
                        <dt>{% trans "File-size" %}</dt>
                        <dd>{{ original.size|filesizeformat }}</dd>
                    {% endif %}
                    {% if original.modified_at %}
                        <dt>{% trans "Modified" %}</dt>
                        <dd>{{ original.modified_at }}</dd>
                    {% endif %}
                    {% if original.uploaded_at %}
                        <dt>{% trans "Created" %}</dt>
                        <dd>{{ original.uploaded_at }}</dd>
                    {% endif %}
                </dl>
                <div class="image-actions">
                    <ul class="actions-list">
                        <li>
                            <span class="icon fa fa-user"></span>
                            {% if original.owner %}
                                <span class="text">{% trans "Owner" %}: <strong>{{ original.owner }}</strong></span>
                            {% endif %}
                        </li>
                    </ul>
                </div>
            {% endif %}
        </div>
    </section>
